simplify.Coupon

Package simplify :: Class Coupon |
[hide private]
[frames] | no frames]

# Class Coupon

source code

    domain.Domain --+
                    |
                   Coupon

A Coupon object.

Instance Methods | [hide private]
delete(self, *auth_args) Delete this object | source code
update(self, *auth_args) Updates this object | source code
Inherited from `domain.Domain`: `__getitem__`, `__init__`, `__setitem__`, `__str__`, `class_name`, `to_dict`

Static Methods | [hide private]
create(params, *auth_args) Creates an Coupon object | source code
list(criteria=None, *auth_args) Retrieve Coupon objects. | source code
find(object_id, *auth_args) Retrieve a Coupon object from the API | source code

Method Details | [hide private]

### create(params, *auth_args) Static Method | source code
Creates an Coupon object Parameters: `params` - a dict of parameters; valid keys are: `amountOff`: Amount off of the price of the product in the smallest units of the currency of the merchant. While this field is optional, you must provide either amountOff or percentOff for a coupon. Example: 100 = $1.00 [min value: 1] `couponCode`: Code that identifies the coupon to be used. [min length: 2] required `description`: A brief section that describes the coupon. `durationInMonths`: DEPRECATED - Duration in months that the coupon will be applied after it has first been selected. [min value: 1, max value: 9999] `endDate`: Last date of the coupon in UTC millis that the coupon can be applied to a subscription. This ends at 23:59:59 of the merchant timezone. `maxRedemptions`: Maximum number of redemptions allowed for the coupon. A redemption is defined as when the coupon is applied to the subscription for the first time. [min value: 1] `numTimesApplied`: The number of times a coupon will be applied on a customer's subscription. [min value: 1, max value: 9999] `percentOff`: Percentage off of the price of the product. While this field is optional, you must provide either amountOff or percentOff for a coupon. The percent off is a whole number. [min value: 1, max value: 100] `startDate`: First date of the coupon in UTC millis that the coupon can be applied to a subscription. This starts at midnight of the merchant timezone. required `auth_args` - an Authentication object used for the API call. If no value is passed the gloabl keys simplify.public_key and simplify.private_key are used. For backwards compatibility the public and private keys may be passed instead of an Authentication object. `private_api_key` - Private key to use for the API call. If `None`, the value of `simplify.private_key` will be used. Returns: a Coupon object

### delete(self, *auth_args) | source code
Delete this object Parameters: `auth_args` - an Authentication object used for the API call. If no value is passed the gloabl keys simplify.public_key and simplify.private_key are used. For backwards compatibility the public and private keys may be passed instead of an Authentication object.

### list(criteria=None, *auth_args) Static Method | source code
Retrieve Coupon objects. Parameters: `criteria` - a dict of parameters; valid keys are: `filter` <table class="filter_list"><tr><td>filter.id</td><td>Filter by the coupon Id</td></tr><tr><td>filter.text</td><td>Filter by the coupon code</td></tr><tr><td>filter.dateCreatedMin<sup>*</sup></td><td>Filter by the minimum created date you are searching for - Date in UTC millis</td></tr><tr><td>filter.dateCreatedMax<sup>*</sup></td><td>Filter by the maximum created date you are searching for - Date in UTC millis</td></tr><tr><td>filter.startDateMin</td><td>Filter by the minimum coupon start date you are searching for - Date in UTC millis</td></tr><tr><td>filter.startDateMax</td><td>Filter by the maximum coupon start date you are searching for - Date in UTC millis</td></tr><tr><td>filter.endDateMin</td><td>Filter by the minimum coupon end date you are searching for - Date in UTC millis</td></tr><tr><td>filter.endDateMax</td><td>Filter by the maximum coupon end date you are searching for - Date in UTC millis</td></tr></table><br><sup>*</sup>Use dateCreatedMin with dateCreatedMax in the same filter if you want to search between two created dates `max` Allows up to a max of 50 list items to return. [min value: 0, max value: 50, default: 20] `offset` Used in paging of the list. This is the start offset of the page. [min value: 0, default: 0] `sorting` Allows for ascending or descending sorting of the list. The value maps properties to the sort direction (either `asc` for ascending or `desc` for descending). Sortable properties are: `dateCreated` `maxRedemptions` `timesRedeemed` `id` `startDate` `endDate` `percentOff` `couponCode` `durationInMonths` `numTimesApplied` `amountOff`. `auth_args` - an Authentication object used for the API call. If no value is passed the gloabl keys simplify.public_key and simplify.private_key are used. For backwards compatibility the public and private keys may be passed instead of an Authentication object. Returns: an object which contains the list of Coupon objects in the <code>list</code> property and the total number of objects available for the given criteria in the <code>total</code> property.

### find(object_id, *auth_args) Static Method | source code
Retrieve a Coupon object from the API Parameters: `object_id` - ID of object to retrieve `auth_args` - an Authentication object used for the API call. If no value is passed the gloabl keys simplify.public_key and simplify.private_key are used. For backwards compatibility the public and private keys may be passed instead of an Authentication object. Returns: a Coupon object

### update(self, *auth_args) | source code
Updates this object The properties that can be updated: `endDate` The ending date in UTC millis for the coupon. This must be after the starting date of the coupon. `maxRedemptions` Maximum number of redemptions allowed for the coupon. A redemption is defined as when the coupon is applied to the subscription for the first time. [min value: 1] Parameters: `auth_args` - an Authentication object used for the API call. If no value is passed the gloabl keys simplify.public_key and simplify.private_key are used. For backwards compatibility the public and private keys may be passed instead of an Authentication object. Returns: a Coupon object.